#!/usr/bin/gawk -f

# Mivel nem tudjuk előre, hogy milyen kiterjesztéseink lesznek, ezért használjunk tömböt!
# Fontosabb tudnivalók a tömbökről AWK-ban:
#   - Dinamikus méretűek: nem kell előre megmondani a méretüket, futásidőben lehet őket bővíteni.
#   - Asszociatív tömbök: minden tömbelem lényegében egy kulcs-érték pár. Fontos, hogy az asszociatív
#     tömbökben minden kulcs csak egyszer szerepelhet. Az asszociatív tömböket valahogyan így kell elképzelni:
#     T tömb: ["a": 10, "b": 20, "c": 30] (ez nem pontos szintaxis, csak szemléltetés).
#     Néhány fontosabb művelet:
#       * "b" kulcshoz tartozó érték elérése:     T["b"]
#       * "b" kulcshoz tartozó érték módosítása:  T["b"] = 40 ("b" kulcs már van a tömbben, ekkor módosítás történik)
#       * új kulcs-érték pár beszúrása a tömbbe:  T["d"] = 50 ("d" kulcs még nincs a tömbben, ekkor beszúrás történik).
#   - Ha a kulcs-érték párokat nem adjuk meg expliciten, akkor alapértelmezetten a tömbindexek lesznek a kulcsok.
#     FIGYELEM! AWK-ban a tömböket 1-től kezdődően indexeljük (nem 0-tól kezdődően, ahogy más nyelvekben csinálnánk)!
#     Például, ha a T2 tömb a következő: ["alma", "körte", "szilva"], akkor a T2[1] az "alma" értékre fog hivatkozni.

# Az `ls -l` parancs kimenetének első sorában szerepel egy "total <SZÁM>" sor, amit nem szeretnénk feldolgozni. Emiatt
# csak az első soron kívüli sorokat vizsgáljuk (NR = Number of Records = az aktuális sor sorszáma).

NR != 1 {
	# A fájlnév a 9. oszlopban található, ezt fogjuk feldarabolni pont karakter mentén. A darabolás eredményét egy
	# fajlnev_darabok nevű tömbben fogjuk visszakapni, amelyben a kulcsok hagyományos tömbindexek lesznek.
	split($9, fajlnev_darabok, ".")
	
	# A kiterjesztés a pont karakter utáni rész lesz, tehát a fajlnev_darabok tömb második eleme kell nekünk.
	# A feladatleírásnak megfelelően a fájl kiterjesztését csupa kisbetűssé alakítjuk.
	kiterjesztes = tolower(fajlnev_darabok[2])
	
	# Össze akarjuk számolni, hogy az egyes kiterjesztésekből mennyi fordul elő a bemeneti fájlban. Ezt az összegzést
	# egy eredmeny nevű tömbben tesszük meg. A kulcsok a kiterjesztések lesznek, az értékek pedig az adott kiterjesztés
	# előfordulási száma. Ha már szerepel az adott kiterjesztés kulcsként, akkor 1-gyel megnöveljük a hozzá tartozó
	# előfordulást. Ha pedig még nem láttuk korábban az adott kiterjesztést, akkor belerakjuk a tömbbe új kulcsként,
	# 1-es kezdőértékkel. Az alábbi sor pontosan ezt csinálja (emlékezzünk, hogy nem lehet ismétlődő kulcs a tömbben).
	eredmeny[kiterjesztes]++
}

END {
	# A program végén bejárjuk az eredménytömböt, és kiíratjuk, hogy az egyes kiterjesztésekből (kit) mennyi fordult
	# elő (eredmeny[kit]) a bemeneti fájlban.
	
	for (kit in eredmeny) {
		print eredmeny[kit] " darab " kit " fajl"
	}
}
